@@ -21,7 +21,7 @@
 #' @param clamdir The directory where the clam runs reside. Defaults to \code{coredir="clam_runs"}.
 #' @param bacondir The directory where the Bacon runs reside. Defaults to \code{coredir="Plum_runs"}.
 #' @param sep The separator for the .csv files. Defaults to \code{sep=","}.
-#' @param cc Calibration curve for C-14 dates: \code{cc=1} for IntCal13 (northern hemisphere terrestrial), \code{cc=2} for Marine13 (marine),
+#' @param cc Calibration curve for C-14 dates: \code{cc=1} for IntCal20 (northern hemisphere terrestrial), \code{cc=2} for Marine20 (marine),
 #' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
 #' @export
 clam2bacon <- function(core, clamdir="clam_runs", bacondir="Plum_runs", sep=",", cc=1) {
@@ -60,13 +60,6 @@ clam2bacon <- function(core, clamdir="clam_runs", bacondir="Plum_runs", sep=",",
 #' @param bacondir The directory where the Bacon runs reside. Defaults to \code{coredir="Plum_runs"}.
 #' @param clamdir The directory where the clam runs reside. Defaults to \code{coredir="clam_runs"}.
 #' @param sep The separator for the .csv files. Defaults to \code{sep=","}.
-#' @examples{
-#' \donttest{
-#'  tmpfl <- tempfile()
-#'   Bacon(run=FALSE, ask=FALSE, coredir=tmpfl)
-#'   bacon2clam("MSB2K", bacondir=tmpfl, clamdir=tmpfl)
-#'  }
-#' }
 #' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
 #' @export
 bacon2clam <- function(core, bacondir="Plum_runs", clamdir="clam_runs", sep=",") {
@@ -110,9 +103,6 @@ bacon2clam <- function(core, bacondir="Plum_runs", clamdir="clam_runs", sep=",")
 #' @author Maarten Blaauw, J. Andres Christen
 #' @return A list of folders
 #' @param coredir The directory where the Bacon runs reside. Defaults to \code{coredir="Plum_runs"}.
-#' @examples
-#'   Bacon(run=FALSE, coredir=tempfile())
-#'   Plum_runs()
 #' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
 #' @export
 Plum_runs <- function(coredir=get('info')$coredir)
@@ -128,9 +118,6 @@ Plum_runs <- function(coredir=get('info')$coredir)
 #' @return A message stating that the files and settings of this run have been deleted.
 #' @param set Detailed information of the current run, stored within this session's memory as variable \code{info}.
 #' @author Maarten Blaauw, J. Andres Christen
-#' @examples
-#'   Bacon(run=FALSE, coredir=tempfile())
-#'   Bacon.cleanup()
 #' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
 #' @export
 Bacon.cleanup <- function(set=get('info')) {
@@ -219,7 +206,7 @@ assign_coredir <- function(coredir, core, ask=TRUE) {
       if((name[5] %in% cc.names) && min(dets[,5]) >= 0 && max(dets[,5]) <= 4) {} else # extra check for correct values
         stop("unexpected name or values in fifth column (cc, should be between 0 and 4). Please check the manual for guidelines in producing a correct .csv file.\n", call.=FALSE)
     } else
-      if(ncol(dets) == 6) { # probably an 'old' file: dR, dSTD, but could also be cc and delta.R (so no column for delta.STD)
+      if(ncol(dets) == 6) { # probably an 'old' file: dR, dSTD, but could also be cc and delta.R (so no column for delta.STD), and could also be Pb-210 data!
         if(name[5] %in% dR.names && name[6] %in% dSTD.names) {
 			message("\nHELP!!! 6!!!")
           dets <- cbind(dets[,1:4], rep(cc, nrow(dets)), dets[,5:6]) # some shuffling
@@ -422,11 +409,11 @@ assign_coredir <- function(coredir, core, ask=TRUE) {
   fl <- file(set$bacon.file, "w")
   cat("## Ran on", set$date, "\n\n", file=fl)
   cat("Cal 0 : ConstCal;\nCal 1 : ",
-  if(set$cc1=="IntCal13" || set$cc1=="\"IntCal13\"") "IntCal13"
+  if(set$cc1=="IntCal20" || set$cc1=="\"IntCal20\"") "IntCal20"
     else noquote(set$cc1), ", ", set$postbomb, ";\nCal 2 : ",
-  if(set$cc2=="Marine13" || set$cc2=="\"Marine13\"") "Marine13"
+  if(set$cc2=="Marine20" || set$cc2=="\"Marine20\"") "Marine20"
     else noquote(set$cc2), ";\nCal 3 : ",
-  if(set$cc3=="SHCal13" || set$cc3=="\"SHCal13\"") "SHCal13"
+  if(set$cc3=="SHCal20" || set$cc3=="\"SHCal20\"") "SHCal20"
     else noquote(set$cc3), ", ", set$postbomb, ";",
   if(set$cc4=="ConstCal" || set$cc4=="\"ConstCal\"") set$cc4 <- c()
     else
